Welcome to Khoj

# Merge AI with your brain

Hi {{name}}! We are psyched to be part of your journey with personal AI. To better help you, we're committed to staying transparent, accessible, and completely open-source.

Get Started

You're about to get a whole lot more productive.

### Ditch the search bar

You don't need to click around Google results and sift through information yourself, because Khoj is connected to the internet.

### Get a village, not just an agent

Khoj can fill the need for more specialized assistance, such as tutoring, with its curated agents. You get a whole team, always available.

### Available where you are

Build on top of your digital brain. Khoj stores whatever data you share with it, so you can get answers from your personal notes and documents in your native language. You can engage from your desktop, Obsidian, WhatsApp, or the web.

### Create rich, contextual images

With your shared data, Khoj can help you create astoundingly personal images depicting scenes of what's important to you.

Like something? Dislike something? Searching for some other magical feature? Our inbox is always open for feedback! Contact us on team@khoj.dev at anytime.

- The Khoj Team

Docs | GitHub | Twitter | LinkedIn | Discord